exceptiontools.ParallelError
============================

.. abjad-lineage:: abjad.tools.exceptiontools.ParallelError.ParallelError

.. autoclass:: abjad.tools.exceptiontools.ParallelError.ParallelError
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.ParallelError.ParallelError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ParallelError.ParallelError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ParallelError.ParallelError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ParallelError.ParallelError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ParallelError.ParallelError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ParallelError.ParallelError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ParallelError.ParallelError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ParallelError.ParallelError.__unicode__
   :noindex:
